@@ -4,7 +4,7 @@ from collections import OrderedDict
 from django.contrib.gis.gdal import GDALException
 from django.contrib.gis.geos import GEOSException, GEOSGeometry
 from django.core.exceptions import ValidationError
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from rest_framework.fields import Field, SerializerMethodField
 
 __all__ = ['GeometryField', 'GeometrySerializerMethodField']
